Index: build/android/buildbot_functions.sh |
diff --git a/build/android/buildbot_functions.sh b/build/android/buildbot_functions.sh |
index 9ad5d492e272e226ae2794e77f030b7c64d53a0a..bb7f6f45552aca282d77165f540676619da8c26b 100755 |
--- a/build/android/buildbot_functions.sh |
+++ b/build/android/buildbot_functions.sh |
@@ -22,11 +22,11 @@ function bb_setup_environment { |
} |
# Install the build deps by running |
# build/install-build-deps-android.sh. This may update local tools. |
# $1: source root. |
function bb_install_build_deps { |
echo "@@@BUILD_STEP install build deps android@@@" |
- local script="$1/build/install-build-deps-android.sh" |
+ local script="$1/build/install-build-deps-android-sdk.sh" |
if [[ -f "$script" ]]; then |
"$script" |
else |
@@ -22,11 +22,11 @@ function bb_setup_environment { |
} |
# Install the build deps by running |
-# build/install-build-deps-android.sh. This may update local tools. |
+# build/install-build-deps-android-sdk.sh. This may update local tools. |
# $1: source root. |
function bb_install_build_deps { |